@@ -69,7 +69,9 @@ class MongonautViewMixin(object):
                     
     def get_permissions(self, context={}):
         """ Provides permissions for mongoadmin for use in the context"""
-        context['has_permission'] = self.mongoadmin.has_permission(self.request)
-        context['has_staff_permission'] = self.mongoadmin.has_staff_permission(self.request)        
+        context['has_view_permission'] = self.mongoadmin.has_view_permission(self.request)
+        context['has_edit_permission'] = self.mongoadmin.has_edit_permission(self.request)
+        context['has_add_permission'] = self.mongoadmin.has_add_permission(self.request)
+        context['has_delete_permission'] = self.mongoadmin.has_delete_permission(self.request)
         return context
             
\ No newline at end of file
