@@ -1,14 +1,16 @@
 try:
     import floppyforms as forms
 except ImportError:
-    from django import forms
-    
-# TODO add default widgets    
+    from django import forms  
 
 class BaseMongoAdmin(object):
     
     search_fields = []
     
+    # Show the fields to be displayed as columns
+    # TODO: Confirm that this is what the Django admin uses
+    list_fields = []
+    
     #This shows up on the DocumentListView of the Posts
     list_actions = [] 
     
@@ -29,21 +31,25 @@ class BaseMongoAdmin(object):
     formfield_overrides = {}
     readonly_fields = ()
     ordering = None
-
     
-    def has_permission(self, request):
+    def has_view_permission(self, request):
         """
         Returns True if the given HttpRequest has permission to view
         *at least one* page in the mongonaut site.
         """
-        return request.user.is_active
+        return request.user.is_authenticated() and request.user.is_active()
 
-    def has_staff_permission(self, request):
-        """
-        Returns True if the given HttpRequest has permission to view
-        *at least one* page in the mongonaut site.
-        """
-        return request.user.is_active and request.user.is_staff
+    def has_edit_permission(self, request):
+        """ Can edit this object """
+        return request.user.is_authenticated() and request.user.is_active() and request.user.is_staff()
+
+    def has_add_permission(self, request):
+        """ Can add this object """
+        return request.user.is_authenticated() and request.user.is_active() and request.user.is_staff()
+
+    def has_delete_permission(self, request):
+        """ Can delete this object """
+        return request.user.is_authenticated() and request.user.is_active() and request.user.is_admin()
 
 
 class MongoAdmin(BaseMongoAdmin):
