@@ -3,6 +3,7 @@ from datetime import datetime
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.forms.widgets import DateTimeInput, CheckboxInput
+from django.http import HttpResponseForbidden
 from django.views.generic import DetailView
 from django.views.generic import ListView
 from django.views.generic import TemplateView
@@ -105,7 +106,10 @@ class DocumentListView(FormView, MongonautViewMixin):
         # Part of upcoming list view form functionality
         if self.queryset.count():
             context['keys'] = ['id',]
-            for key in sorted([x for x in self.document._fields.keys() if x != 'id']):
+            
+            # Show those items for which we've got list_fields on the mongoadmin
+            for key in [x for x in self.document._fields.keys() if x != 'id' and x in self.mongoadmin.list_fields]:
+                
                 # TODO - Figure out why this EmbeddedDocumentField and ListField breaks this view
                 # Note - This is the challenge part, right? :)
                 if isinstance(self.document._fields[key], EmbeddedDocumentField):            
@@ -117,6 +121,7 @@ class DocumentListView(FormView, MongonautViewMixin):
         if self.mongoadmin.search_fields:
             context['search_field'] = True
 
+        context = self.get_permissions(context)
         return context
 
     def post(self, request, *args, **kwargs):
@@ -162,19 +167,19 @@ class DocumentDetailView(TemplateView, MongonautViewMixin):
         return context
  
 
-class DocumentDetailFormView(FormView, MongonautViewMixin):
+class DocumentDetailEditFormView(FormView, MongonautViewMixin):
     """ :args: <app_label> <document_name> <id> """#
 
-    template_name = "mongonaut/document_detail_form.html"
+    template_name = "mongonaut/document_detail_edit_form.html"
     form_class = DocumentDetailForm
     success_url = '/'
     
     def get_success_url(self):
         self.set_mongonaut_base()  
-        return reverse('document_detail_form', kwargs={'app_label':self.app_label,'document_name':self.document_name,'id':self.kwargs.get('id')})    
+        return reverse('document_detail_edit_form', kwargs={'app_label':self.app_label,'document_name':self.document_name,'id':self.kwargs.get('id')})    
     
     def get_context_data(self, **kwargs):
-        context = super(DocumentDetailFormView, self).get_context_data(**kwargs)
+        context = super(DocumentDetailEditFormView, self).get_context_data(**kwargs)
         self.set_mongonaut_base()
         self.document_type = getattr(self.models, self.document_name)
         self.ident = self.kwargs.get('id')
@@ -186,12 +191,6 @@ class DocumentDetailFormView(FormView, MongonautViewMixin):
             
         self.set_mongoadmin()
         context = self.get_permissions(context)
-        #self.form = DocumentDetailForm()
-        #context['form'] = document_detail_form_munger(self.form, self.document_type, self.document)
-        
-        #if self.request.method == 'POST':
-        #    context['form'].data = self.request.POST
-        #    context['form'].is_bound = True
 
         return context
         
@@ -201,7 +200,7 @@ class DocumentDetailFormView(FormView, MongonautViewMixin):
         self.ident = self.kwargs.get('id')
         self.document = self.document_type.objects.get(id=self.ident)
         self.form = DocumentDetailForm()        
-        self.form = document_detail_form_factory(self.form, self.document_type, self.document)
+        self.form = document_detail_form_factory(form=self.form, document_type=self.document_type, initial=self.document)
         if self.request.method == 'POST':
             self.form.data = self.request.POST
             self.form.is_bound = True
@@ -235,6 +234,73 @@ class DocumentDetailFormView(FormView, MongonautViewMixin):
             
         return self.form
         
+class DocumentDetailAddFormView(FormView, MongonautViewMixin):
+    """ :args: <app_label> <document_name> <id> """#
+
+    template_name = "mongonaut/document_detail_add_form.html"
+    form_class = DocumentDetailForm
+    success_url = '/'
+
+    def get_success_url(self):
+        self.set_mongonaut_base()  
+        return reverse('document_detail', kwargs={'app_label':self.app_label,'document_name':self.document_name,'id':str(self.document.id)})
+
+    def get_context_data(self, **kwargs):
+        """ TODO - possibly inherit this from DocumentDetailEditFormView. This is same thing minus:
+            self.ident = self.kwargs.get('id')
+            self.document = self.document_type.objects.get(id=self.ident)
+        """
+        context = super(DocumentDetailAddFormView, self).get_context_data(**kwargs)
+        self.set_mongonaut_base()
+        self.document_type = getattr(self.models, self.document_name)
+
+        context['app_label'] = self.app_label  
+        context['document_name'] = self.document_name
+
+        self.set_mongoadmin()
+        context = self.get_permissions(context)
+
+        return context
+
+    def get_form(self, DocumentDetailForm):
+        self.set_mongonaut_base()
+        self.document_type = getattr(self.models, self.document_name)
+        self.form = DocumentDetailForm()        
+        self.form = document_detail_form_factory(form=self.form, document_type=self.document_type)
+        if self.request.method == 'POST':
+            self.form.data = self.request.POST
+            self.form.is_bound = True
+            if self.form.is_valid():
+                self.document = self.document_type()              
+                for key, field in self.form.fields.items():                      
+                    if 'readonly' in field.widget.attrs:
+                        # For _id
+                        # TODO - make the ones below work
+                        # for ReferenceField - like <class 'articles.models.User'> on Blog                        
+                        # For ListField - like 'field': <mongoengine.fields.StringField object at 0x101b51810>,                                
+                        # For EmbeddedDocumentField
+                        continue       
+
+                    if isinstance(field.widget, DateTimeInput):
+                        format = field.widget.format
+                        setattr(self.document, key, datetime.strptime(self.request.POST[key], format))
+                        continue
+
+                    if isinstance(field.widget, CheckboxInput):
+                        if key in self.request.POST:
+                            setattr(self.document, key, True)
+                        else:
+                            setattr(self.document, key, False)
+                        continue
+
+                    # for strings
+                    setattr(self.document, key, self.request.POST[key])
+                self.document.save()
+                # TODO add message for save
+
+
+        return self.form        
+        
     
 
 class EmbeddedDocumentDetailView(DetailView, MongonautViewMixin):
