@@ -5,6 +5,7 @@ from django import forms
 from mongoengine.base import ObjectIdField
 from mongoengine.fields import BooleanField
 from mongoengine.fields import DateTimeField
+from mongoengine.fields import EmbeddedDocumentField
 from mongoengine.fields import ListField
 from mongoengine.fields import ReferenceField
 
@@ -16,7 +17,8 @@ def get_widget(field, disabled=False):
     if disabled or \
             isinstance(field, ObjectIdField) or \
             isinstance(field, ListField) or \
-            isinstance(field, ReferenceField):
+            isinstance(field, ReferenceField) or \
+            isinstance(field, EmbeddedDocumentField):
         attrs['class'] += ' disabled'
         attrs['readonly'] = 'readonly'
     
